%define anolis_release 3
%ifarch loongarch64 riscv64
%bcond_without ignore_lua
%bcond_with libbpf_tools
%else
%bcond_with ignore_lua
%bcond_without libbpf_tools
%endif


Name:           bcc
Version:        0.32.0
Release:        %{anolis_release}%{?dist}
Summary:        BPF Compiler Collection (BCC)
License:        Apache-2.0
URL:            https://github.com/iovisor/bcc
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake >= 2.8.12 llvm-devel clang-devel llvm-googletest
BuildRequires:  flex bison python3-setuptools
BuildRequires:  elfutils-libelf-devel elfutils-debuginfod-client-devel
BuildRequires:  ncurses-devel python3-devel libxml2-devel
BuildRequires:  libbpf-devel >= 1.0.0 libbpf-static >= 1.0.0

%if %{without ignore_lua}
BuildRequires:  pkgconfig(luajit)
%endif

Requires:       libbpf >= 2:0.8.0-1 tar
Recommends:     kernel-devel
Recommends:     %{name}-tools = %{EVR}

ExclusiveArch:  x86_64 aarch64 loongarch64 riscv64

%description
BCC is a toolkit for creating efficient kernel tracing and manipulation
programs, and includes several useful tools and examples. It makes use of
extended BPF (Berkeley Packet Filters), formally known as eBPF, a new feature
that was first added to Linux 3.15. BCC makes BPF programs easier to write,
with kernel instrumentation in C (and includes a C wrapper around LLVM), and
front-ends in Python and lua. It is suited for many tasks, including
performance analysis and network traffic control.


%package devel
Summary:        Shared library for BPF Compiler Collection (BCC)
Requires:       %{name} = %{EVR}
Suggests:       elfutils-debuginfod-client

%description devel
The %{name}-devel package contains libraries and header files for developing
application that use BPF Compiler Collection (BCC).

%package doc
Summary:        Examples for BPF Compiler Collection (BCC)
Recommends:     python3-%{name} = %{EVR}
Recommends:     %{name}-lua = %{EVR}
BuildArch:      noarch

%description doc
Examples for BPF Compiler Collection (BCC)

%package -n python3-%{name}
Summary:        Python3 bindings for BPF Compiler Collection (BCC)
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description -n python3-%{name}
Python3 bindings for BPF Compiler Collection (BCC)

%if %{without ignore_lua}
%package lua
Summary:        Standalone tool to run BCC tracers written in Lua
Requires:       %{name} = %{EVR}

%description lua
Standalone tool to run BCC tracers written in Lua
%endif

%package tools
Summary:        Command line tools for BPF Compiler Collection (BCC)
Requires:       bcc = %{EVR}
Requires:       python3-%{name} = %{EVR}
Requires:       python3-netaddr

%description tools
Command line tools for BPF Compiler Collection (BCC)
%if %{with libbpf_tools}
%package -n libbpf-tools
Summary:        Command line libbpf tools for BPF Compiler Collection (BCC)
BuildRequires:  libbpf-devel >= 2:0.8.0-1, libbpf-static >= 2:0.8.0-1
BuildRequires:  bpftool

%description -n libbpf-tools
Command line libbpf tools for BPF Compiler Collection (BCC)
%endif

%prep
%autosetup -p1

%build
%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo \
       -DREVISION_LAST=%{version} -DREVISION=%{version} -DPYTHON_CMD=python3 \
       -DCMAKE_USE_LIBBPF_PACKAGE:BOOL=TRUE -DENABLE_NO_PIE=OFF \
       -DENABLE_LLVM_SHARED=1
%cmake_build
%if %{with libbpf_tools}
pushd libbpf-tools
make BPFTOOL=bpftool LIBBPF_OBJ=%{_libdir}/libbpf.a CFLAGS="%{optflags}" LDFLAGS="%{build_ldflags}" USE_BLAZESYM=0
make DESTDIR=./tmp-install prefix= install
(
    cd tmp-install/bin
    for file in *; do
        mv $file bpf-$file
    done
    for file in `find . -type l`; do
        dest=$(readlink "$file")
        ln -s -f bpf-$dest $file
    done
)
popd
%endif

%install
%cmake_install

find %{buildroot}%{_datadir}/%{name}/{tools,examples} -type f -exec \
  sed -i -e '1s=^#!/usr/bin/python\([0-9.]\+\)\?$=#!%{__python3}=' \
         -e '1s=^#!/usr/bin/env python\([0-9.]\+\)\?$=#!%{__python3}=' \
         -e '1s=^#!/usr/bin/env bcc-lua$=#!/usr/bin/bcc-lua=' {} \;

mkdir -p %{buildroot}%{_mandir}
mv %{buildroot}%{_datadir}/%{name}/man/* %{buildroot}%{_mandir}/
for i in `find %{buildroot}%{_mandir} -name "*.gz"`; do
  tname=$(basename $i)
  rename $tname %{name}-$tname $i
done

mkdir -p %{buildroot}%{_docdir}/%{name}
mv %{buildroot}%{_datadir}/%{name}/examples %{buildroot}%{_docdir}/%{name}/

rm -rf %{buildroot}%{_datadir}/%{name}/tools/old/
%if %{with libbpf_tools}
mkdir -p %{buildroot}/%{_sbindir}
install -p libbpf-tools/tmp-install/bin/* %{buildroot}/%{_sbindir}/
%endif

%generate_compatibility_deps

%files
%license LICENSE.txt
%{_libdir}/lib%{name}.so.*
%{_libdir}/libbcc_bpf.so.*

%dir %{abidir}
%{abidir}/lib%{name}*.dump
%license LICENSE.txt

%files devel
%exclude %{_libdir}/lib%{name}*.a
%exclude %{_libdir}/lib%{name}*.la
%{_libdir}/lib%{name}.so
%{_libdir}/libbcc_bpf.so
%{_libdir}/pkgconfig/lib%{name}.pc
%{_includedir}/%{name}/
%{abidir}/lib%{name}*.dump

%files -n python3-%{name}
%{python3_sitelib}/%{name}*

%files doc
%doc README.md
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/examples/

%files tools
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/tools/
%{_datadir}/%{name}/introspection/
%{_mandir}/man8/*

%if %{without ignore_lua}
%files lua
%{_bindir}/bcc-lua
%endif

%if %{with libbpf_tools}
%files -n libbpf-tools
%{_sbindir}/bpf-*
%{abidir}/bpf-*-option.list
%endif

%changelog
* Fri May 30 2025 Yihao Yan <yan.yihao@zte.com.cn> - 0.32.0-3
- enabled riscv build

* Thu May 8 2025 Yihao Yan <yan.yihao@zte.com.cn> - 0.32.0-2
- add support for riscv64

* Wed Feb 19 2025 Zhao Hang <wb-zh951434@alibaba-inc.com> - 0.32.0-1
- Update to 0.32.0-1 from 0.30.0-1
- Migrated to SPDX license

* Wed May 08 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.30.0-1
- update to 0.30.0

* Thu Mar 28 2024 Zhao Hang <wb-zh951434@alibaba-inc.com> - 0.27.0-5
- Rebuild with python3.11

* Thu Mar 21 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.27.0-4
- Rebuild with new llvm

* Mon Mar 11 2024 Bo Ren <rb01097748@alibaba-inc.com> - 0.27.0-3
- Rebuild with python3.11

* Tue Nov 14 2023 Wenlong Zhang<zhangwenlong@loongson.cn> - 0.27.0-2
- disable luajit and bpftool for loongarch64

* Mon Apr 17 2023 Funda Wang <fundawang@yeah.net> - 0.27.0-1
- New version 0.27.0

* Thu Apr 13 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 0.26.0-1
- Update to 0.26.0
- Fix man page conflict

* Wed Feb 15 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 0.25.0-1
- update to 0.25.0
- add ali enhenced tools for fs, schedule and sys
- fix man pages installation dir (Funda Wang)

* Thu May 5 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.24.0-1
- Init from upstream  version 0.24.0
